//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCVPOLY_H
#define WSCVPOLY_H

#include <WScom.h>
#include <WSCvpolyAttr.h>
#define WSCvpoly_VER  1000

class WSCvpoly :public WSCvpolyAttr{

  protected:
    short* _line_x;
    short* _line_y;
    char*  _data_x;
    char*  _data_y;
    WSCuchar _line_num;

    WSMFpropertyDef(WSNlineX,   char*, _data_x  );
    WSMFpropertyDef(WSNlineY,   char*, _data_y  );
    WSMFpropertyDef(WSNlineNum, WSCuchar, _line_num);

    WSDLEX32 long	_set_data_num(short num);

  public:
    WSDLEX32 WSCvpoly(WSCbase* base, char* name);
    WSDLEX32 virtual ~WSCvpoly();
    WSDLEX32 virtual long draw();

    WSMFguiClassDef(WSCvpoly, WSCvpolyAttr);
    WSMFversionDef  (WSCvpoly);
};
#endif
